@@ -24,19 +24,24 @@
 
 #include "decorators.h"
 
+#include <string>
+
+using std::string;
+
 class SpanDecorator : public TextDecorator
 {
  protected:
-  char *span ;
+  string span ;
 
  public:
-  SpanDecorator( TextGenerator *t, CharTranslator *, char *ta);
+  SpanDecorator( TextGenerator *t, CharTranslator *, const string &ta);
+  virtual ~SpanDecorator() {}
 
   virtual void startDecorate();
   virtual void endDecorate();
 
  protected:
-  void startTAG( char *span ) const;
+  void startTAG( ) const;
   void endTAG( ) const;
 } ;
 
