@@ -27,16 +27,17 @@
 class CssGeneratorFactory : public HtmlGeneratorFactory
 {
  protected:
-  virtual TextDecorator *createBoldDecorator(TextGenerator *);
-  virtual TextDecorator *createItalicDecorator(TextGenerator *);
-  virtual TextDecorator *createUnderlineDecorator(TextGenerator *);
-  virtual TextDecorator *createColorDecorator(TextGenerator *, char *color);
+  virtual TextGenerator *createBoldDecorator(TextGenerator *);
+  virtual TextGenerator *createItalicDecorator(TextGenerator *);
+  virtual TextGenerator *createUnderlineDecorator(TextGenerator *);
+  virtual TextGenerator *createColorDecorator(TextGenerator *, const string &color);
 
-  virtual TextGenerator *createGenerator(TextGenerator *final_dec, char *key);
+  virtual TextGenerator *createGenerator(TextGenerator *final_dec, const string &key);
 
  public:
-  CssGeneratorFactory(bool line_number) :
-    HtmlGeneratorFactory (line_number) {}
+  CssGeneratorFactory(bool line_number, const string &t, const string &input,
+                       const string &header, const string &foot, const string &css) :
+    HtmlGeneratorFactory (line_number, t, input, header, foot, css) {}
 };
 
 #endif // CSSGENERATORFACTORY_H
