@@ -25,7 +25,8 @@
 #include "globalostream.h"
 
 TagDecorator::TagDecorator( TextGenerator *t, CharTranslator *tr,
-                            char *ta, char *a, char *v ) : 
+                            const string &ta, const string &a,
+                            const string &v ) :
   TextDecorator (t, tr), tag(ta), attr(a), val(v)
 {
 }
@@ -33,20 +34,20 @@ TagDecorator::TagDecorator( TextGenerator *t, CharTranslator *tr,
 void
 TagDecorator::startDecorate()
 {
-  startTAG( tag, attr, val ) ;
-}
-  
-void
-TagDecorator::endDecorate()
-{
-  endTAG( tag ) ;
+  startTAG( ) ;
 }
 
 void
-TagDecorator::startTAG( char *tag, char *attr, char *val ) const
+TagDecorator::endDecorate()
+{
+  endTAG( ) ;
+}
+
+void
+TagDecorator::startTAG( ) const
 {
   (*sout) << "<" << tag ;
-  if ( attr && val )
+  if ( attr.size () && val.size () )
     generateAttrVal ();
   (*sout) << ">" ;
 }
@@ -58,14 +59,14 @@ TagDecorator::generateAttrVal() const
 }
 
 void
-TagDecorator::endTAG( char *tag ) const
+TagDecorator::endTAG( ) const
 {
   (*sout) << "</" << tag << ">" ;
 }
 
 // ColorDecorator
 ColorDecorator::ColorDecorator( TextGenerator *t, CharTranslator *tr,
-                                char *color ) :
+                                const string &color ) :
   TagDecorator( t, tr, FONT_TAG, COLOR_TAG, color )
 {
 }
