@@ -27,15 +27,24 @@
 class HtmlGeneratorFactory : public GeneratorFactory
 {
  protected:
-  virtual TextDecorator *createBoldDecorator(TextGenerator *);
-  virtual TextDecorator *createItalicDecorator(TextGenerator *);
-  virtual TextDecorator *createUnderlineDecorator(TextGenerator *);
-  virtual TextDecorator *createColorDecorator(TextGenerator *, char *color);
+  string input_file_name;
+  string doc_header;
+  string doc_footer;
+  string css_url;
 
+  virtual TextGenerator *createBoldDecorator(TextGenerator *);
+  virtual TextGenerator *createItalicDecorator(TextGenerator *);
+  virtual TextGenerator *createUnderlineDecorator(TextGenerator *);
+  virtual TextGenerator *createColorDecorator(TextGenerator *, const string &color);
+
+  virtual DocGenerator *createDocGenerator();
+  virtual ColorMap *createColorMap();
   virtual CharTranslator *createCharTranslator();
 
  public:
-  HtmlGeneratorFactory(bool line_number);
+  HtmlGeneratorFactory(bool line_number, const string &t, const string &input,
+                       const string &header, const string &foot, const string &css);
+  virtual ~HtmlGeneratorFactory() {}
 };
 
 #endif // HTMLGENERATORFACTORY_H
