@@ -28,7 +28,8 @@ class XhtmlTagDecorator : public TagDecorator
 {
  public:
   XhtmlTagDecorator( TextGenerator *t, CharTranslator *, 
-                     char *ta, char *a, char *v );
+                     const string &ta, const string &a,
+                     const string &v );
 
  protected:
   virtual void generateAttrVal() const;
@@ -37,7 +38,7 @@ class XhtmlTagDecorator : public TagDecorator
 class XhtmlColorDecorator : public XhtmlTagDecorator
 {
  public:
-  XhtmlColorDecorator( TextGenerator *t, CharTranslator *, char *color );
+  XhtmlColorDecorator( TextGenerator *t, CharTranslator *, const string &color );
 };
 
 #endif
