@@ -27,14 +27,17 @@
 class XHtmlGeneratorFactory : public HtmlGeneratorFactory
 {
  protected:
-  virtual TextDecorator *createBoldDecorator(TextGenerator *);
-  virtual TextDecorator *createItalicDecorator(TextGenerator *);
-  virtual TextDecorator *createUnderlineDecorator(TextGenerator *);
-  virtual TextDecorator *createColorDecorator(TextGenerator *, char *color);
+  virtual TextGenerator *createBoldDecorator(TextGenerator *);
+  virtual TextGenerator *createItalicDecorator(TextGenerator *);
+  virtual TextGenerator *createUnderlineDecorator(TextGenerator *);
+  virtual TextGenerator *createColorDecorator(TextGenerator *, const string &color);
 
  public:
-  XHtmlGeneratorFactory(bool line_number) :
-    HtmlGeneratorFactory (line_number) {}
+  XHtmlGeneratorFactory(bool line_number, const string &t, const string &input,
+                       const string &header, const string &foot, const string &css) :
+    HtmlGeneratorFactory (line_number, t, input, header, foot, css) {}
+
+  virtual DocGenerator *createDocGenerator();
 };
 
 #endif // XHTMLGENERATORFACTORY_H
