@@ -37,8 +37,6 @@ using std::ifstream;
 static void file_error(const char *error, char *file);
 static void internal_error(const char *error);
 
-#define OUTPUT_EXTENSION ".html"
-
 char *
 read_file(char *fileName)
 {
@@ -93,9 +91,9 @@ internal_error(const char *error)
   exit (1);
 }
 
-// output file name = <outputDir> + input file name + ".html"
+// output file name = <outputDir> + input file name + ext
 char *
-createOutputFileName( char *inputFileName, char *outputDir )
+createOutputFileName( char *inputFileName, char *outputDir, const char *ext )
 {
   char *input_file_name;
   char path_separator = '/';
@@ -122,7 +120,7 @@ createOutputFileName( char *inputFileName, char *outputDir )
     }
 
   int lenght =  strlen(input_file_name) + 
-    strlen(OUTPUT_EXTENSION) + 1 ;
+    strlen(ext) + 1 ;
   int output_dir_lenght = 0;
   
   if (outputDir)
@@ -141,7 +139,7 @@ createOutputFileName( char *inputFileName, char *outputDir )
       outputFileName[output_dir_lenght + 1] = '\0';
     }
   strcat (outputFileName, input_file_name);
-  strcat (outputFileName, OUTPUT_EXTENSION);
+  strcat (outputFileName, ext);
 
   return outputFileName ;
 }
