@@ -6,7 +6,7 @@
 using std::istream;
 
 char *read_file(char *fileName);
-char *createOutputFileName( char *inputFileName, char *outputDir );
+char *createOutputFileName( char *inputFileName, char *outputDir, const char *ext );
 unsigned int get_line_count(char *file_name);
 unsigned int get_line_count(istream &input);
 
