@@ -18,6 +18,7 @@
  */
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <iostream>
 #include <string.h>
 
@@ -35,16 +36,18 @@
 #include "copyright.h"
 #include "reportbugs.h"
 
-// FIXME: 
+// FIXME:
 #include "htmlgeneratorfactory.h"
 #include "xhtmlgeneratorfactory.h"
 #include "cssgeneratorfactory.h"
+#include "escgeneratorfactory.h"
 
 // for globals
 #include "linenumdigit.h"
 #include "globalostream.h"
 #include "cmdlineargs.h"
 #include "generators.h"
+#include "globalcolormap.h"
 
 using std::cout;
 using std::endl;
@@ -63,6 +66,10 @@ unsigned int line_num_digit = 0; // num of digits to represent line number
 
 gengetopt_args_info args_info ;     // command line structure
 
+ColorMap *MapOfColors;
+
+static void print_cgi_header();
+
 StartApp::StartApp() :
   entire_doc (0), verbose (0), cssUrl (0),
   use_css (0), is_cgi (0)
@@ -74,13 +81,13 @@ extern int parseTags() ;
 int
 StartApp::start(int argc, char * argv[])
 {
-  char *docTitle;  
-  char *docHeader; // the buffer with the header  
+  char *docTitle;
+  char *docHeader; // the buffer with the header
   char *docFooter; // the buffer with the footer
   char *header_fileName = 0;
   char *footer_fileName = 0;
   unsigned i;
-  int v; 
+  int v;
 
 #ifdef BUILD_AS_CGI
   // map environment to parameters if used as CGI
@@ -90,9 +97,9 @@ StartApp::start(int argc, char * argv[])
   argv = temp_argv;
 #endif // BUILD_AS_CGI
 
-  if((v = cmdline_parser(argc, argv, &args_info)) != 0) 
-    // calls cmdline parser. The user gived bag args if it doesn't return -1 
-    return 1; 
+  if((v = cmdline_parser(argc, argv, &args_info)) != 0)
+    // calls cmdline parser. The user gived bag args if it doesn't return -1
+    return 1;
 
   if (args_info.version_given)
     {
@@ -111,21 +118,29 @@ StartApp::start(int argc, char * argv[])
 
   bool format_html = (strcmp (args_info.out_format_arg, "html") == 0);
   bool format_xhtml = (strcmp (args_info.out_format_arg, "xhtml") == 0);
+  bool format_esc = (strcmp (args_info.out_format_arg, "esc") == 0);
 
-  if (! format_html && ! format_xhtml)
+  const char *ext = 0;
+
+  if (! format_html && ! format_xhtml && ! format_esc)
     {
       cerr << PACKAGE << ": output format " << args_info.out_format_arg
            << " not recognized" << endl;
       exit (1);
     }
 
+  if (format_html || format_xhtml)
+    ext = ".html";
+  else
+    ext = ".txt";
+
   /* initialization of global symbols */
   inputFileName = outputFileName = 0 ;
   sout = 0 ;
   docTitle = 0 ;
   docHeader = 0 ;
   docFooter = 0 ;
-  
+
   docTitle = args_info.title_arg ;
   header_fileName = args_info.header_arg ;
   footer_fileName = args_info.footer_arg ;
@@ -146,12 +161,12 @@ StartApp::start(int argc, char * argv[])
 
   entire_doc = ( args_info.doc_given || (docTitle != 0) || use_css ||
                  docHeader || docFooter ) ;
-  
+
   inputFileName = args_info.input_arg ;
   if ( inputFileName && ! is_cgi )
     outputFileName = args_info.output_arg ;
-  
-  bool generate_to_stdout = 
+
+  bool generate_to_stdout =
     (args_info.output_arg &&
      strcmp (args_info.output_arg, "STDOUT") == 0);
 
@@ -160,53 +175,92 @@ StartApp::start(int argc, char * argv[])
 
   printMessage( PACKAGE ) ;
   printMessage( VERSION ) ;
-  
+
   parseTags() ;
 
   GeneratorFactory *generator_factory = 0;
 
-  if( use_css )
+  if (format_esc)
     {
-      generator_factory =
-        new CssGeneratorFactory (args_info.line_number_given);
+      if (use_css)
+        {
+          cerr << PACKAGE << ": cannot use css with esc output format" << endl;
+          exit (1);
+        }
+
+      generator_factory = new EscGeneratorFactory
+        (args_info.line_number_given);
     }
   else
     {
-      if (format_xhtml && ! args_info.css_given)
-        generator_factory =
-          new XHtmlGeneratorFactory (args_info.line_number_given);
-      else
-        generator_factory =
-          new HtmlGeneratorFactory (args_info.line_number_given);
-    }
-  
+     string title;
+     string input_name;
+     string doc_header;
+     string doc_footer;
+     string css_url;
+
+     if (docTitle)
+       title = docTitle;
+     if (inputFileName)
+       input_name = inputFileName;
+     if ((! docTitle) && inputFileName)
+        title = inputFileName;
+     if (docHeader)
+       doc_header = docHeader;
+     if (docFooter)
+       doc_footer = docFooter;
+     if (cssUrl)
+       css_url = cssUrl;
+
+     if( use_css )
+       {
+         generator_factory =
+           new CssGeneratorFactory (args_info.line_number_given,
+               title, input_name, doc_header,
+               doc_footer, css_url);
+       }
+     else
+       {
+         if (format_xhtml && ! args_info.css_given)
+           generator_factory =
+             new XHtmlGeneratorFactory
+              (args_info.line_number_given, title, input_name, doc_header,
+               doc_footer, css_url);
+         else
+           generator_factory =
+            new HtmlGeneratorFactory
+             (args_info.line_number_given, title, input_name, doc_header,
+               doc_footer, css_url);
+       }
+     }
+
   generator_factory->createGenerators ();
 
   if ( is_cgi )
     print_cgi_header() ;
 
   // let's start the translation :-)
-  
+
   // first the --input file
   if ( ! args_info.inputs_num )
     processFile( args_info.src_lang_arg, args_info.out_format_arg,
-    		 inputFileName, 
-                 (generate_to_stdout ? 0 : outputFileName), 
-                 docTitle, docHeader, docFooter, entire_doc, cssUrl ) ;
+    		 inputFileName,
+                 (generate_to_stdout ? 0 : outputFileName),
+                 entire_doc ) ;
 
   // let's process other files, if there are any
   if ( args_info.inputs_num && !is_cgi ) {
     for ( i = 0 ; i < (args_info.inputs_num) ; ++i ) {
       processFile( args_info.src_lang_arg, args_info.out_format_arg,
-      		   args_info.inputs[i], 
+      		   args_info.inputs[i],
                    (generate_to_stdout ? 0 :
 		   createOutputFileName (args_info.inputs[i],
-                                         args_info.output_dir_arg)),
-		   docTitle, docHeader, docFooter, entire_doc, cssUrl ) ; 
+                                         args_info.output_dir_arg, ext)),
+		   entire_doc) ;
       cerr << "Processed " << args_info.inputs[i] << endl ;
     }
   }
-  
+
   return (0 );
 }
 
@@ -233,3 +287,11 @@ StartApp::print_version()
 {
   cout << "GNU " << PACKAGE << " " << VERSION << endl;
 }
+
+void
+print_cgi_header()
+{
+  printf( "Content-type: text/html\n" ) ;
+  printf( "\n" ) ;
+}
+
