@@ -20,7 +20,7 @@ import java.io.* ;
 public class Hello {
     int foo = 1998 ;
     int hex_foo = 0xCAFEBABE;
-    boolean b ;
+    boolean b = false;
     Integer i = null ;
     char c = '\'', d = 'n', e = '\\' ;
     String xml = "<tag attr=\"value\">&auml;</tag>", foo2 = "\\" ;
